
// MainFrm.cpp : implementation of the CMainFrame class
//

#include "stdafx.h"
#include "TeeTest.h"

#include "MainFrm.h"

#include "TeeChart\TeeChartDefines.h"
#include "TeeChart\canvas.h"
#include "TeeChart\series.h"
#include "TeeChart\barseries.h"
#include "TeeChart\zoom.h"
#include "TeeChart\scroll.h"
#include "TeeChart\environment.h"
#include "TeeChart\aspect.h"
#include "TeeChart\teegdiplus.h"
#include "TeeChart\marks.h"
#include "TeeChart\teefont.h"
#include "TeeChart\pen.h"
#include "TeeChart\teeshadow.h"
#include "TeeChart\axes.h"
#include "TeeChart\axis.h"
#include "TeeChart\axislabels.h"

#define ID_CHART1		1000

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

// CMainFrame

IMPLEMENT_DYNAMIC(CMainFrame, CFrameWnd)

BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
	ON_WM_CREATE()
	ON_WM_DESTROY()
END_MESSAGE_MAP()

BEGIN_EVENTSINK_MAP(CMainFrame, CFrameWnd)
END_EVENTSINK_MAP()

static UINT indicators[] =
{
	ID_SEPARATOR,           // status line indicator
	ID_INDICATOR_CAPS,
	ID_INDICATOR_NUM,
	ID_INDICATOR_SCRL,
};

// CMainFrame construction/destruction

CMainFrame::CMainFrame() 
{
}

CMainFrame::~CMainFrame()
{
}

int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
	Gdiplus::GdiplusStartupInput gdiPlusStartupInput;
	Gdiplus::GdiplusStartup(&m_GdiPlusToken, &gdiPlusStartupInput, NULL);

	if (CFrameWnd::OnCreate(lpCreateStruct) == -1)
		return -1;

    CRect rect;
    GetClientRect(rect);

	CRect chart1Rect(rect);

	m_pChart1 = std::unique_ptr<CTChart>(new CTChart());
    if (!m_pChart1->Create("Chart 1", WS_CHILD|WS_VISIBLE, chart1Rect, this, ID_CHART1))
		return -1;
	m_pChart1->GetAspect().GetGDIPlus().SetActive(false);
	m_pChart1->GetAspect().SetView3D(false);

	if (!m_wndStatusBar.Create(this))
	{
		TRACE0("Failed to create status bar\n");
		return -1;      // fail to create
	}
	m_wndStatusBar.SetIndicators(indicators, sizeof(indicators)/sizeof(UINT));

	AddSeries(0, 10);
	AddSeries(10, 10);

	return 0;
}

void CMainFrame::AddSeries(int xstart, int count)
{
	long seriesIndex = m_pChart1->AddSeries(scBar);
	CSeries& series = m_pChart1->Series(seriesIndex);

	series.GetAsBar().SetUseOrigin(false);
	series.GetAsBar().SetAutoBarSize(true);
	series.GetAsBar().SetMultiBar(mbNone);

	series.GetAsBar().SetMarksOnBar(TRUE);
	series.GetAsBar().SetMarksLocation(mlStart);

	CMarks& marks = series.GetMarks();

	marks.SetAngle(90);
	marks.GetFont().GetShadow().SetColor(RGB(0,0,0));
	marks.GetFont().GetShadow().SetHorizSize(1);
	marks.GetFont().GetShadow().SetVertSize(1);
	marks.GetFont().GetShadow().SetSmooth(false);
	marks.GetFont().GetShadow().SetVisible(TRUE);
	marks.GetFont().SetColor(RGB(192,192,192));
	marks.GetFont().SetBold(TRUE);
	//marks.SetClip(TRUE);
	marks.SetTextAlign(aCenter);
	marks.SetTransparent(TRUE);
	marks.GetArrow().SetVisible(false);
	marks.GetShadow().SetVisible(false);

	CAxisLabels& axisLabels = m_pChart1->GetAxis().GetBottom().GetLabels();

	int x = xstart;
	for (int i = 0; i < count; ++i)
	{
		int rvalue = rand();

		CString strRValue;
		strRValue.Format("%d", rvalue);

		int rlabel = rand();
		
		int modulus = i % 5;
		modulus *= 10;

		if (modulus != 0)
			rlabel %= modulus;

		if (rvalue < 10000)
			rlabel = -rlabel;

		CString strRValueLabel;
		strRValueLabel.Format("%d", rlabel);

		rlabel = rand();
		
		CString strRAxisLabel;
		strRAxisLabel.Format("%d", rlabel);

		series.AddXY(x, rvalue, strRValueLabel.GetBuffer(), clTeeColor);
		axisLabels.Add(x++, strRAxisLabel);
	}
}

afx_msg void CMainFrame::OnDestroy()
{
	Gdiplus::GdiplusShutdown(m_GdiPlusToken);
}

BOOL CMainFrame::PreCreateWindow(CREATESTRUCT& cs)
{
	if( !CFrameWnd::PreCreateWindow(cs) )
		return FALSE;
	// TODO: Modify the Window class or styles here by modifying
	//  the CREATESTRUCT cs

	cs.dwExStyle &= ~WS_EX_CLIENTEDGE;
	cs.lpszClass = AfxRegisterWndClass(0);
	return TRUE;
}

// CMainFrame diagnostics

#ifdef _DEBUG
void CMainFrame::AssertValid() const
{
	CFrameWnd::AssertValid();
}

void CMainFrame::Dump(CDumpContext& dc) const
{
	CFrameWnd::Dump(dc);
}
#endif //_DEBUG


// CMainFrame message handlers

